==> haskell-bsb-http-chunked-0.0.0.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bsb-http-chunked
version: 0.0.0.2
id: bsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg
key: bsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg
license: BSD-3-Clause
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
stability: Provisional
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).
    .
    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.
category: Data, Network
abi: 92d097cad2581e79eea8c7ac3d9e40cc
exposed: True
exposed-modules:
    Data.ByteString.Builder.HTTP.Chunked
hidden-modules: Blaze.ByteString.Builder.Char8
                Blaze.ByteString.Builder.Compat.Write
                Blaze.ByteString.Builder.Internal.Write
import-dirs: /usr/lib/ghc-8.4.3/site-local/bsb-http-chunked-0.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/bsb-http-chunked-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/bsb-http-chunked-0.0.0.2
hs-libraries: HSbsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock
haddock-html: /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bsb-http-chunked-0.0.0.3-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bsb-http-chunked
version: 0.0.0.3
id: bsb-http-chunked-0.0.0.3-6EXORfWzGzV3asmcr7Q6Gt
key: bsb-http-chunked-0.0.0.3-6EXORfWzGzV3asmcr7Q6Gt
license: BSD-3-Clause
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
           (c) 2018 Simon Jakobi
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi
stability: Provisional
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).
    .
    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.
category: Data, Network
abi: 1021a089950be06905c4ead25b79991b
exposed: True
exposed-modules:
    Data.ByteString.Builder.HTTP.Chunked
import-dirs: /usr/lib/ghc-8.4.3/site-local/bsb-http-chunked-0.0.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/bsb-http-chunked-0.0.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/bsb-http-chunked-0.0.0.3
hs-libraries: HSbsb-http-chunked-0.0.0.3-6EXORfWzGzV3asmcr7Q6Gt
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock
haddock-html: /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
